#!/bin/bash

function quit {
	echo $1
	service npcd start
	exit -1
}

PNPPATH=/opt/monitor/op5/pnp

if [ "$1" = "-h" ] || [ "$1" = "--help" ];
then
	echo "Usage: fix_host_graphs.sh [-h] [--help]"
	echo "This script add a datasource for packetloss to the ping graphs generated by"
	echo "check_icmp if (and only if) it is missing. So it is safe to run script whenever"
	echo "you need. To restore old db's use: tar -zxf /tmp/host_rrds.tar.gz"
	echo "To delete graphs backup use: rm /tmp/host_rrds.tar.gz"
	exit
fi

if ! [ -x $PNPPATH/rrdaddsource-1.2 ];
then
	quit "rrdaddsource-1.2 is not in $PNPPATH !"
fi

service npcd stop

cd $PNPPATH/perfdata || exit
tar -zcf /tmp/host_rrds.tar.gz */_HOST_* || quit "Can not create a backup !"

for i in $(find . -name _HOST_.rrd)
do
	DS_COUNT=$(rrdtool info $i |grep '^ds\[3' |wc -l)
	if [ $DS_COUNT == 0 ]
	then
		echo "$DS_COUNT $i - modifying..."
		mv $i $i.bak && echo "Host backup was created" || quit "Can not create Host backup for file $i"
		su -c "$PNPPATH/rrdaddsource-1.2 $PNPPATH/perfdata/$i.bak $PNPPATH/perfdata/$i 3:GAUGE:8460:0:100" - monitor
		rm $i.bak && echo "Host backup was removed"
	fi
done

echo "Conversion complete."
echo "Note: If you are sure then remove backup /tmp/host_rrds.tar.gz"

service npcd start || quit "Can not start ncpd daemon !"
